==> consent-management-lib-1.13-sources.jar: de/adorsys/psd2/consent/repository/EventRepository.java <==
/*
 * Copyright 2018-2018 adorsys GmbH & Co KG
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.adorsys.psd2.consent.repository;

import de.adorsys.psd2.consent.domain.event.EventEntity;
import de.adorsys.psd2.xs2a.core.event.EventOrigin;
import de.adorsys.psd2.xs2a.core.event.EventType;
import org.springframework.data.repository.CrudRepository;

import java.time.OffsetDateTime;
import java.util.List;

public interface EventRepository extends CrudRepository<EventEntity, Long> {
    List<EventEntity> findByTimestampBetweenOrderByTimestampAsc(OffsetDateTime from, OffsetDateTime to);

    List<EventEntity> findByTimestampBetweenAndConsentIdOrderByTimestampAsc(OffsetDateTime from, OffsetDateTime to, String consentId);

    List<EventEntity> findByTimestampBetweenAndPaymentIdOrderByTimestampAsc(OffsetDateTime from, OffsetDateTime to, String paymentId);

    List<EventEntity> findByTimestampBetweenAndEventTypeOrderByTimestampAsc(OffsetDateTime from, OffsetDateTime to, EventType eventType);

    List<EventEntity> findByTimestampBetweenAndEventOriginOrderByTimestampAsc(OffsetDateTime from, OffsetDateTime to, EventOrigin eventOrigin);
}

==> consent-management-lib-3.3.1-sources.jar: de/adorsys/psd2/consent/repository/EventRepository.java <==
/*
 * Copyright 2018-2018 adorsys GmbH & Co KG
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.adorsys.psd2.consent.repository;

import de.adorsys.psd2.consent.domain.event.EventEntity;
import de.adorsys.psd2.xs2a.core.event.EventOrigin;
import de.adorsys.psd2.xs2a.core.event.EventType;
import org.springframework.data.jpa.repository.JpaSpecificationExecutor;
import org.springframework.data.repository.CrudRepository;

import java.time.OffsetDateTime;
import java.util.List;

public interface EventRepository extends CrudRepository<EventEntity, Long>, JpaSpecificationExecutor<EventEntity> {
    List<EventEntity> findByTimestampBetweenOrderByTimestampAsc(OffsetDateTime from, OffsetDateTime to);

    List<EventEntity> findByTimestampBetweenAndEventTypeOrderByTimestampAsc(OffsetDateTime from, OffsetDateTime to, EventType eventType);

    List<EventEntity> findByTimestampBetweenAndEventOriginOrderByTimestampAsc(OffsetDateTime from, OffsetDateTime to, EventOrigin eventOrigin);
}
